package commands

import (
	"fmt"
	"hash/crc32"
)

var (
	adjectives = [...]string{
		"active",
		"admiring",
		"adoring",
		"agitated",
		"amazing",
		"angry",
		"astral",
		"awesome",
		"best",
		"big",
		"bitter",
		"blissful",
		"blue",
		"bold",
		"boring",
		"brave",
		"brief",
		"bright",
		"broad",
		"hyggelig",
		"busy",
		"calm",
		"charming",
		"classic",
		"clever",
		"boolean",
		"colorful",
		"common",
		"complex",
		"constant",
		"cool",
		"cranky",
		"crazy",
		"current",
		"cyan",
		"dark",
		"dazzling",
		"deep",
		"dreamy",
		"dry",
		"dull",
		"eager",
		"cloudy",
		"ecstatic",
		"elastic",
		"elated",
		"elegant",
		"eloquent",
		"empty",
		"epic",
		"equal",
		"exciting",
		"extreme",
		"fake",
		"familiar",
		"fervent",
		"festive",
		"fierce",
		"final",
		"fine",
		"first",
		"flat",
		"focused",
		"formal",
		"found",
		"friendly",
		"frosty",
		"full",
		"funny",
		"gallant",
		"general",
		"genuine",
		"gifted",
		"glad",
		"good",
		"goofy",
		"gracious",
		"grand",
		"great",
		"green",
		"happy",
		"heavy",
		"high",
		"hopeful",
		"hungry",
		"illegal",
		"initial",
		"internal",
		"inverted",
		"jolly",
		"jovial",
		"junior",
		"keen",
		"kind",
		"last",
		"laughing",
		"local",
		"long",
		"lost",
		"lucid",
		"lunar",
		"magenta",
		"magical",
		"major",
		"middle",
		"minor",
		"mobile",
		"modest",
		"musing",
		"old",
		"national",
		"natural",
		"new",
		"neat",
		"negative",
		"nervous",
		"next",
		"nice",
		"nifty",
		"normal",
		"northern",
		"ochre",
		"opposite",
		"ordinary",
		"original",
		"ornery",
		"other",
		"peaceful",
		"pedantic",
		"pensive",
		"personal",
		"physical",
		"pink",
		"polar",
		"polished",
		"positive",
		"possible",
		"precious",
		"previous",
		"public",
		"purple",
		"quirky",
		"raw",
		"red",
		"regular",
		"relaxed",
		"relevant",
		"remote",
		"reverent",
		"reversed",
		"rich",
		"rough",
		"round",
		"royal",
		"sad",
		"safe",
		"second",
		"secret",
		"senior",
		"serene",
		"sharp",
		"shiny",
		"silly",
		"simple",
		"sleepy",
		"smooth",
		"soft",
		"solid",
		"fabulous",
		"spare",
		"specific",
		"stoic",
		"strange",
		"supreme",
		"sweet",
		"tall",
		"tender",
		"third",
		"thirsty",
		"toit",
		"top",
		"total",
		"tropical",
		"trusting",
		"ultimate",
		"unique",
		"upbeat",
		"upper",
		"upstairs",
		"usual",
		"valuable",
		"vast",
		"vibrant",
		"vigilant",
		"vigorous",
		"western",
		"rounded",
		"wild",
		"wizardly",
		"working",
		"worn",
		"yellow",
		"young",
		"youthful",
		"zealous",
		"zen",
	}

	nouns = [...]string{
		"access",
		"accident",
		"account",
		"act",
		"action",
		"activity",
		"actor",
		"ad",
		"addition",
		"address",
		"advice",
		"affair",
		"age",
		"agency",
		"agent",
		"air",
		"airline",
		"airport",
		"alarm",
		"alcohol",
		"ambition",
		"amount",
		"analysis",
		"analyst",
		"anger",
		"angle",
		"animal",
		"answer",
		"anxiety",
		"appeal",
		"apple",
		"area",
		"argument",
		"arrival",
		"art",
		"article",
		"aside",
		"aspect",
		"assist",
		"attempt",
		"attitude",
		"audience",
		"author",
		"average",
		"award",
		"back",
		"bad",
		"bag",
		"bake",
		"balance",
		"band",
		"bank",
		"bar",
		"base",
		"baseball",
		"basis",
		"basket",
		"bat",
		"bath",
		"battle",
		"beach",
		"beer",
		"bell",
		"belt",
		"bench",
		"bend",
		"benefit",
		"bet",
		"bicycle",
		"bid",
		"bike",
		"bill",
		"bird",
		"birthday",
		"bit",
		"bite",
		"bitter",
		"blame",
		"blank",
		"blind",
		"block",
		"board",
		"boat",
		"bonus",
		"book",
		"boot",
		"border",
		"boss",
		"bother",
		"bottle",
		"bowl",
		"box",
		"brain",
		"branch",
		"bread",
		"breath",
		"brick",
		"bridge",
		"brush",
		"budget",
		"bug",
		"building",
		"bunch",
		"bus",
		"business",
		"button",
		"buyer",
		"cabinet",
		"cable",
		"cake",
		"calendar",
		"camera",
		"camp",
		"campaign",
		"candle",
		"candy",
		"cap",
		"capital",
		"car",
		"card",
		"care",
		"career",
		"carpet",
		"carry",
		"case",
		"cash",
		"cat",
		"catch",
		"category",
		"cause",
		"cell",
		"chain",
		"chair",
		"champion",
		"chance",
		"channel",
		"chapter",
		"charity",
		"chart",
		"chicken",
		"chip",
		"choice",
		"church",
		"city",
		"class",
		"clerk",
		"click",
		"client",
		"climate",
		"clock",
		"closet",
		"clothes",
		"cloud",
		"club",
		"clue",
		"coach",
		"coast",
		"coat",
		"code",
		"coffee",
		"cold",
		"collar",
		"college",
		"comment",
		"company",
		"computer",
		"concept",
		"concert",
		"conflict",
		"contact",
		"contest",
		"context",
		"contract",
		"control",
		"cookie",
		"copy",
		"corner",
		"cost",
		"counter",
		"country",
		"county",
		"couple",
		"courage",
		"course",
		"court",
		"cover",
		"cow",
		"steel",
		"craft",
		"creative",
		"credit",
		"crew",
		"cross",
		"culture",
		"cup",
		"currency",
		"curve",
		"customer",
		"cycle",
		"damage",
		"data",
		"database",
		"day",
		"deal",
		"dealer",
		"debate",
		"debt",
		"decision",
		"degree",
		"delay",
		"delivery",
		"demand",
		"depth",
		"design",
		"designer",
		"desk",
		"detail",
		"device",
		"diamond",
		"diet",
		"dinner",
		"director",
		"dirt",
		"disaster",
		"discount",
		"disease",
		"dish",
		"disk",
		"display",
		"distance",
		"district",
		"doctor",
		"document",
		"dog",
		"door",
		"dot",
		"draft",
		"drama",
		"drawer",
		"drawing",
		"dream",
		"drink",
		"drive",
		"driver",
		"drop",
		"dust",
		"duty",
		"ear",
		"earth",
		"ease",
		"east",
		"economy",
		"edge",
		"editor",
		"effect",
		"effort",
		"egg",
		"election",
		"elevator",
		"emotion",
		"emphasis",
		"employee",
		"employer",
		"end",
		"energy",
		"engine",
		"engineer",
		"entrance",
		"entry",
		"error",
		"essay",
		"estate",
		"evening",
		"event",
		"evidence",
		"exam",
		"example",
		"exchange",
		"excuse",
		"exercise",
		"exit",
		"expert",
		"extent",
		"eye",
		"fact",
		"factor",
		"failure",
		"fall",
		"fan",
		"farm",
		"farmer",
		"fault",
		"fear",
		"feature",
		"fee",
		"feedback",
		"feeling",
		"field",
		"fight",
		"figure",
		"file",
		"film",
		"finance",
		"finding",
		"fire",
		"fish",
		"fishing",
		"flight",
		"floor",
		"flower",
		"fly",
		"focus",
		"food",
		"foot",
		"football",
		"force",
		"form",
		"fortune",
		"frame",
		"freedom",
		"friend",
		"front",
		"fruit",
		"fuel",
		"fun",
		"function",
		"future",
		"game",
		"gap",
		"garage",
		"keyboard",
		"garden",
		"gas",
		"gate",
		"gear",
		"gene",
		"gift",
		"glass",
		"glove",
		"goal",
		"gold",
		"golf",
		"grade",
		"grass",
		"grocery",
		"ground",
		"group",
		"growth",
		"guess",
		"guest",
		"guidance",
		"guide",
		"guitar",
		"habit",
		"hair",
		"half",
		"hall",
		"handle",
		"harm",
		"hat",
		"head",
		"health",
		"hearing",
		"heart",
		"heat",
		"height",
		"highway",
		"history",
		"holiday",
		"home",
		"homework",
		"honey",
		"hook",
		"hope",
		"horse",
		"hospital",
		"host",
		"hotel",
		"hour",
		"house",
		"housing",
		"ice",
		"idea",
		"ideal",
		"image",
		"impact",
		"incident",
		"income",
		"industry",
		"injury",
		"insect",
		"inside",
		"instance",
		"interest",
		"internet",
		"iron",
		"island",
		"issue",
		"item",
		"jacket",
		"job",
		"joint",
		"joke",
		"judge",
		"judgment",
		"juice",
		"jury",
		"key",
		"kind",
		"king",
		"kitchen",
		"lab",
		"lack",
		"ladder",
		"lake",
		"land",
		"language",
		"law",
		"lawyer",
		"layer",
		"leader",
		"league",
		"leather",
		"lecture",
		"length",
		"lesson",
		"letter",
		"level",
		"library",
		"lie",
		"life",
		"light",
		"limit",
		"line",
		"link",
		"list",
		"living",
		"loan",
		"location",
		"lock",
		"log",
		"lorry",
		"loss",
		"low",
		"luck",
		"lunch",
		"machine",
		"magazine",
		"mail",
		"mall",
		"manager",
		"manner",
		"map",
		"mark",
		"market",
		"master",
		"match",
		"material",
		"math",
		"matter",
		"maximum",
		"meal",
		"meaning",
		"media",
		"medicine",
		"medium",
		"meeting",
		"memory",
		"menu",
		"mess",
		"message",
		"metal",
		"method",
		"midnight",
		"mind",
		"minimum",
		"minute",
		"mirror",
		"mission",
		"mistake",
		"mixture",
		"mode",
		"moment",
		"money",
		"monitor",
		"month",
		"mood",
		"morning",
		"mortgage",
		"motor",
		"mountain",
		"mouse",
		"movie",
		"mud",
		"music",
		"nail",
		"name",
		"nation",
		"nature",
		"neck",
		"nerve",
		"net",
		"network",
		"news",
		"night",
		"noise",
		"north",
		"note",
		"nothing",
		"notice",
		"novel",
		"number",
		"object",
		"occasion",
		"office",
		"officer",
		"official",
		"oil",
		"opening",
		"opinion",
		"option",
		"orange",
		"order",
		"outcome",
		"outside",
		"owner",
		"pace",
		"pack",
		"package",
		"page",
		"paint",
		"painting",
		"pair",
		"panic",
		"paper",
		"park",
		"parking",
		"part",
		"partner",
		"party",
		"passage",
		"path",
		"patience",
		"patient",
		"pattern",
		"pause",
		"payment",
		"peace",
		"peak",
		"pen",
		"penalty",
		"pension",
		"people",
		"period",
		"person",
		"phase",
		"phone",
		"photo",
		"phrase",
		"physics",
		"piano",
		"picture",
		"pie",
		"piece",
		"pin",
		"pipe",
		"pitch",
		"pizza",
		"place",
		"plan",
		"plane",
		"plant",
		"plastic",
		"plate",
		"platform",
		"player",
		"plenty",
		"plug",
		"poem",
		"poet",
		"poetry",
		"point",
		"police",
		"policy",
		"politics",
		"pool",
		"position",
		"post",
		"pot",
		"potato",
		"pound",
		"power",
		"practice",
		"presence",
		"present",
		"pressure",
		"price",
		"pride",
		"primary",
		"priority",
		"prize",
		"problem",
		"process",
		"produce",
		"product",
		"profile",
		"profit",
		"program",
		"progress",
		"project",
		"promise",
		"proof",
		"property",
		"proposal",
		"purchase",
		"purple",
		"purpose",
		"quality",
		"quantity",
		"quarter",
		"question",
		"radio",
		"rain",
		"range",
		"rate",
		"ratio",
		"reaction",
		"reading",
		"reality",
		"reason",
		"recipe",
		"record",
		"region",
		"register",
		"relation",
		"relief",
		"report",
		"republic",
		"request",
		"research",
		"resident",
		"resort",
		"resource",
		"respect",
		"response",
		"rest",
		"result",
		"revenue",
		"review",
		"reward",
		"rice",
		"ring",
		"risk",
		"river",
		"road",
		"rock",
		"role",
		"roof",
		"room",
		"rope",
		"routine",
		"row",
		"ruin",
		"rule",
		"safety",
		"sail",
		"salad",
		"salary",
		"sale",
		"salt",
		"sample",
		"sand",
		"sandwich",
		"savings",
		"scale",
		"scene",
		"schedule",
		"scheme",
		"school",
		"science",
		"scooter",
		"screen",
		"screw",
		"script",
		"sea",
		"search",
		"season",
		"seat",
		"section",
		"sector",
		"security",
		"self",
		"sense",
		"sentence",
		"series",
		"service",
		"session",
		"setting",
		"shape",
		"share",
		"shelter",
		"ship",
		"shirt",
		"shock",
		"shoe",
		"shop",
		"shopping",
		"shot",
		"side",
		"sign",
		"signal",
		"silver",
		"singer",
		"sink",
		"sir",
		"site",
		"size",
		"skate",
		"skill",
		"sky",
		"sleep",
		"slice",
		"slide",
		"smoke",
		"snow",
		"society",
		"sock",
		"software",
		"solution",
		"song",
		"sort",
		"sound",
		"soup",
		"source",
		"south",
		"space",
		"speaker",
		"speech",
		"speed",
		"spend",
		"spirit",
		"spite",
		"sport",
		"spot",
		"spray",
		"square",
		"stable",
		"staff",
		"stage",
		"stand",
		"standard",
		"star",
		"state",
		"station",
		"status",
		"steak",
		"step",
		"stick",
		"stock",
		"storage",
		"store",
		"storm",
		"story",
		"stranger",
		"strategy",
		"street",
		"strength",
		"stress",
		"string",
		"stroller",
		"student",
		"studio",
		"study",
		"stuff",
		"style",
		"subject",
		"success",
		"sugar",
		"suit",
		"summer",
		"sun",
		"support",
		"surgery",
		"surprise",
		"survey",
		"sweet",
		"swimming",
		"swing",
		"switch",
		"sympathy",
		"system",
		"table",
		"tackle",
		"tale",
		"talk",
		"tank",
		"target",
		"task",
		"tax",
		"tea",
		"teacher",
		"teaching",
		"team",
		"tell",
		"tennis",
		"tension",
		"term",
		"test",
		"text",
		"thanks",
		"theme",
		"theory",
		"thing",
		"thought",
		"ticket",
		"till",
		"time",
		"tip",
		"title",
		"toe",
		"tone",
		"tool",
		"tooth",
		"top",
		"topic",
		"tour",
		"tourist",
		"towel",
		"tower",
		"town",
		"track",
		"trade",
		"traffic",
		"trainer",
		"training",
		"trash",
		"treat",
		"tree",
		"trick",
		"trip",
		"trouble",
		"truck",
		"trust",
		"truth",
		"tune",
		"two",
		"type",
		"union",
		"unit",
		"user",
		"vacation",
		"value",
		"variety",
		"vehicle",
		"version",
		"video",
		"view",
		"village",
		"virus",
		"voice",
		"volume",
		"wall",
		"warning",
		"water",
		"wave",
		"way",
		"weakness",
		"wealth",
		"weather",
		"web",
		"wedding",
		"week",
		"weekend",
		"weight",
		"welcome",
		"wheel",
		"while",
		"wind",
		"window",
		"wine",
		"wing",
		"winner",
		"winter",
		"witness",
		"wood",
		"word",
		"work",
		"worker",
		"world",
		"writer",
		"writing",
		"yard",
		"year",
		"youth",
		"zone",
	}
)

func GetRandomName(id []byte) string {
	cutoff := len(id) / 2
	adjectiveIndex := crc32.ChecksumIEEE(id[:cutoff])
	nounIndex := crc32.ChecksumIEEE(id[cutoff:])
	return fmt.Sprintf("%s-%s",
		adjectives[adjectiveIndex%uint32(len(adjectives))],
		nouns[nounIndex%uint32(len(nouns))])
}
